package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.AreaElectricityAttr;

/**
 * 服务区用电属性Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IAreaElectricityAttrService
{
    /**
     * 查询服务区用电属性
     * 
     * @param id 服务区用电属性主键
     * @return 服务区用电属性
     */
     AreaElectricityAttr selectAreaElectricityAttrById(Long id);

    /**
     * 查询服务区用电属性列表
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 服务区用电属性集合
     */
     List<AreaElectricityAttr> selectAreaElectricityAttrList(AreaElectricityAttr areaElectricityAttr);

    /**
     * 新增服务区用电属性
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 结果
     */
     int insertAreaElectricityAttr(AreaElectricityAttr areaElectricityAttr);

    /**
     * 修改服务区用电属性
     * 
     * @param areaElectricityAttr 服务区用电属性
     * @return 结果
     */
     int updateAreaElectricityAttr(AreaElectricityAttr areaElectricityAttr);

    /**
     * 批量删除服务区用电属性
     * 
     * @param ids 需要删除的服务区用电属性主键集合
     * @return 结果
     */
     int deleteAreaElectricityAttrByIds(Long[] ids);

    /**
     * 删除服务区用电属性信息
     * 
     * @param id 服务区用电属性主键
     * @return 结果
     */
     int deleteAreaElectricityAttrById(Long id);
}
